@@ -1,6 +1,5 @@
 #! /usr/bin/python3
 # -*- coding: utf-8 -*-
 
-from .hpxsky import HpxSky
-from .astro import *
+from .astro_tools import *
 
