@@ -361,6 +361,8 @@ class ABeam(Beam):
             raise TypeError(
                 'coords should be ICRS or SkyCoord object'
             )
+        if coords.isscalar:
+            raise ValueError('coords should not be a scalar.')
         if not isinstance(time, Time):
             raise TypeError(
                 'time should be Time object'
@@ -526,6 +528,7 @@ class DBeam(Beam):
                     elana=self.elana,
                     ma=ma
                 )
+                ana.beamsquint = self.beamsquint
                 anavals = ana.beam_values(
                     coords=coords,
                     time=time
