@@ -2,11 +2,21 @@
 # -*- coding: utf-8 -*-
 
 
-"""
+r"""
     ********
     SST Data
     ********
 
+    The most basic data product of `NenuFAR <https://nenufar.obs-nancay.fr/en/astronomer/>`_
+    are the *Spectral STatistics*, also known as *SST* data.
+    They are computed and delivered by the `LaNewBa <https://nenufar.obs-nancay.fr/en/astronomer/#receivers>`_
+    receiver which digitizes :math:`96 \times 2` input signals (96 Mini-Arrays and 2 polarizations) at a
+    sampling frequency of :math:`200\ {\rm MHz}`, further channelized in sub-bands of
+    :math:`200\ {\rm MHz} / 1024 = 195.3125\ {\rm kHz}` bandwidth each.
+    The SST data consist in the gathering of spectra per individual Mini-Array,
+    per second, evaluated at the 2 *NenuFAR* antenna polarizations (*North-West* and *North-East*).
+
+
     Data reading
     ------------
 
@@ -29,7 +39,7 @@
 
     If the :attr:`~nenupy.beamlet.sstdata.SST_Data.altazA` attribute
     is filled with a valid ``'*.altazA'`` file, it returns an instance
-    of :class:`~nenupy.observation.pointing.AnalogPointing` that
+    of :class:`~nenupy.observation.pointing_obs.AnalogPointing` that
     is appropriate to handle the analog pointing(s) of the Mini-Arrays
     during the analyzed observation.
 
@@ -59,8 +69,8 @@
     ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 
     SST FITS files are most often split to only cover one or two hours
-    of observations. In this regard, :class:`~nenupy.beamlet.sstdata.SST_Data`
-    objects have been designed to allow for time concatenantion between
+    of observation. In this regard, :class:`~nenupy.beamlet.sstdata.SST_Data`
+    objects have been designed to allow for time concatenation between
     several :class:`~nenupy.beamlet.sstdata.SST_Data` instances. The
     arithmetic operator *Addition* is used to fill this role.
 
@@ -123,14 +133,22 @@
     Reference
     ---------
 
-    Methods
-    ^^^^^^^
-
-    
-
-    Attributes
-    ^^^^^^^^^^
+    .. autosummary::
+        :nosignatures:
 
+        ~nenupy.beamlet.sstdata.SST_Data
+        ~nenupy.beamlet.sstdata.SST_Data.select
+        ~nenupy.beamlet.sstdata.SST_Data.filename
+        ~nenupy.beamlet.sstdata.SST_Data.altazA
+        ~nenupy.beamlet.sstdata.SST_Data.fMin
+        ~nenupy.beamlet.sstdata.SST_Data.fMax
+        ~nenupy.beamlet.sstdata.SST_Data.freqRange
+        ~nenupy.beamlet.sstdata.SST_Data.ma
+        ~nenupy.beamlet.sstdata.SST_Data.mas
+        ~nenupy.beamlet.sstdata.SST_Data.polar
+        ~nenupy.beamlet.sstdata.SST_Data.tMax
+        ~nenupy.beamlet.sstdata.SST_Data.tMin
+        ~nenupy.beamlet.sstdata.SST_Data.timeRange
 
 """
 
@@ -152,9 +170,9 @@ from astropy.time import Time
 import astropy.units as u
 import numpy as np
 
-from nenupy.base import MiniArrays
+from nenupy.instru import NenuFAR
+from nenupy.astro.pointing import Pointing
 from nenupy.beamlet import SData
-from nenupy.observation import AnalogPointing
 
 import logging
 log = logging.getLogger(__name__)
@@ -166,8 +184,8 @@ log = logging.getLogger(__name__)
 class SST_Data(object):
     """ Class to read *NenuFAR* SST data stored as FITS files.
 
-        :param sstfile: Path to SST file.
-        :type sstfile: `str` or `list`
+        :param filename: Path to SST file.
+        :type filename: `str` or `list`
         :param altazA: Path to ``*.altazA`` file, which describe
             the analogical pointing.
         :type altazA: `str` or `list`
@@ -187,6 +205,7 @@ class SST_Data(object):
 
     def __init__(self, filename, altazA=None, **kwargs):
         self._autoUpdate = kwargs.get('autoUpdate', True)
+        self._allMAs = kwargs.get('allMAs', False)
         self.obsProperties = {}
         self.filename = filename
         self.altazA = altazA
@@ -283,7 +302,7 @@ class SST_Data(object):
         # .altazA file comparison
         if (self.altazA==[]) and (other.altazA==[]):
             sameAltazA = True
-        elif isinstance(self.altazA, AnalogPointing) and isinstance(other.altazA, AnalogPointing):
+        elif isinstance(self.altazA, Pointing) and isinstance(other.altazA, Pointing):
             selfBaseNames = list(map(basename, self.altazA.filename))
             otherBaseNames = list(map(basename, other.altazA.filename))
             sameAltazA = all(
@@ -301,10 +320,16 @@ class SST_Data(object):
     # --------------------- Getter/Setter --------------------- #
     @property
     def filename(self):
-        """
-            :setter: 
+        """ SST FITS file name(s).
+
+            :setter:
+                SST file name(s) to be read. It can be provided
+                by either a single `str` or a `list` of `str`
+                corresponding to the desired FITS file(s).
 
             :getter:
+                List of the SST file name(s) loaded for this
+                instance of :class:`~nenupy.beamlet.sstdata.SST_Data`.
 
             :type: `list`
         """
@@ -324,7 +349,8 @@ class SST_Data(object):
 
     @property
     def altazA(self):
-        """
+        """ Mini-Arrays analog pointing orders file.
+
             :setter: 
 
             :getter:
@@ -337,12 +363,13 @@ class SST_Data(object):
         if (a is None) or (a==[]):
             self._altazA = []
         else:
-            self._altazA = AnalogPointing(filename=a)
+            self._altazA = Pointing.from_file(file_name=a)
 
 
     @property
     def timeRange(self):
-        """
+        """ Sets the start and end times of SST data selection.
+
             :setter: 
 
             :getter:
@@ -365,7 +392,8 @@ class SST_Data(object):
 
     @property
     def freqRange(self):
-        """
+        """ Sets the minimum and maximum frequencies of SST data selection.
+
             :setter: 
 
             :getter:
@@ -388,7 +416,8 @@ class SST_Data(object):
 
     @property
     def polar(self):
-        """
+        """ Sets the polarization of SST data selection.
+
             :setter: 
 
             :getter:
@@ -414,7 +443,8 @@ class SST_Data(object):
 
     @property
     def ma(self):
-        """
+        """ Sets the Mini-Array of SST data selection.
+
             :setter: 
 
             :getter:
@@ -430,16 +460,24 @@ class SST_Data(object):
             raise TypeError(
                 '`ma` should be an integer.'
             )
-        if not all([m in mas for mas in self._getPropList('MAs')]):
-            raise IndexError(
-                'Mini-Array `{}` not used in current observation.'.format(m)
-            )
+        if not self._allMAs:
+            if not all([m in mas for mas in self._getPropList('MAs')]):
+                raise IndexError(
+                    'Mini-Array `{}` not used in current observation.'.format(m)
+                )
+        else:
+            if not all([m in mas for mas in self._getPropList('AllMAs')]):
+                raise IndexError(
+                    'Mini-Array `{}` not present in current observation.'.format(m)
+                )
         self._ma = m
 
 
     @property
     def tMin(self):
-        """
+        """ Gets the start time of the
+            :class:`~nenupy.beamlet.sstdata.SST_Data` instance.
+
             :getter:
 
             :type: :class:`~astropy.time.Time`
@@ -449,7 +487,9 @@ class SST_Data(object):
 
     @property
     def tMax(self):
-        """
+        """ Gets the end time of the
+            :class:`~nenupy.beamlet.sstdata.SST_Data` instance.
+
             :getter:
 
             :type: :class:`~astropy.time.Time`
@@ -484,7 +524,10 @@ class SST_Data(object):
 
             :type: :class:`~nenupy.base.MiniArrays`
         """
-        return self._getPropList('MAs')[0]
+        if self._allMAs:
+            return self._getPropList('AllMAs')[0]
+        else:
+            return self._getPropList('MAs')[0]
 
 
     # --------------------------------------------------------- #
@@ -493,12 +536,16 @@ class SST_Data(object):
         """
             :param freqRange:
             :type freqRange:
+                `list` of :class:`~astropy.units.Quantity`
             :param timeRange:
             :type timeRange:
+                `list` of :class:`~astropy.time.Time`
             :param ma:
             :type ma:
+                `int`
             :param polar:
             :type polar:
+                `str`
 
             :returns:
             :rtype: `~nenupy.beamlet.sdata.SData`
@@ -596,7 +643,10 @@ class SST_Data(object):
             'fMax': ins['frq'].max()*u.MHz,
             'freqs': ins['frq'][0]*u.MHz,
             'polars': ins['spol'][0],
-            'MAs': MiniArrays(ins['noMROn'][0])
+            # 'MAs': MiniArrays(ins['noMROn'][0]),
+            # 'AllMAs': MiniArrays(ins['noMR'][0])
+            'MAs': NenuFAR()[ins['noMROn'][0]],
+            'AllMAs': NenuFAR()[ins['noMR'][0]]
         }
 
 
